==> colobot_0.1.9.orig.tar.gz: colobot-colobot-gold-0.1.9-alpha/src/common/resources/outputstream.h <==
/*
 * This file is part of the Colobot: Gold Edition source code
 * Copyright (C) 2001-2016, Daniel Roux, EPSITEC SA & TerranovaTeam
 * http://epsitec.ch; http://colobot.info; http://github.com/colobot
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://gnu.org/licenses
 */

#pragma once

#include "common/resources/outputstreambuffer.h"

#include <ostream>
#include <string>


class COutputStreamBufferContainer
{
protected:
    COutputStreamBuffer m_buffer;
};

class COutputStream : public COutputStreamBufferContainer, public std::ostream
{
public:
    COutputStream();

    /** Construct and Open Stream for writing
     *
     * \param filename
     * \param Mode one of: std::ios_base::out - Open for writing, std::ios_base::app - Append to file
     *
     */
    COutputStream(const std::string& filename, std::ios_base::openmode mode = std::ios_base::out);
    virtual ~COutputStream();

    /** Open Stream for writing
     *
     * \param filename
     * \param Mode one of: std::ios_base::out - Open for writing, std::ios_base::app - Append to file
     *
     */
    void open(const std::string& filename, std::ios_base::openmode mode = std::ios_base::out);
    void close();
    bool is_open();
};

==> colobot_0.1.11.orig.tar.gz: colobot-colobot-gold-0.1.11-alpha/src/common/resources/outputstream.h <==
/*
 * This file is part of the Colobot: Gold Edition source code
 * Copyright (C) 2001-2016, Daniel Roux, EPSITEC SA & TerranovaTeam
 * http://epsitec.ch; http://colobot.info; http://github.com/colobot
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://gnu.org/licenses
 */

#pragma once

#include "common/resources/outputstreambuffer.h"

#include <ostream>
#include <string>


class COutputStreamBufferContainer
{
protected:
    COutputStreamBuffer m_buffer;
};

class COutputStream : public COutputStreamBufferContainer, public std::ostream
{
public:
    COutputStream();

    /** Construct and Open Stream for writing
     *
     * \param filename
     * \param mode one of: std::ios_base::out - Open for writing, std::ios_base::app - Append to file
     *
     */
    COutputStream(const std::string& filename, std::ios_base::openmode mode = std::ios_base::out);
    virtual ~COutputStream();

    /** Open Stream for writing
     *
     * \param filename
     * \param mode one of: std::ios_base::out - Open for writing, std::ios_base::app - Append to file
     *
     */
    void open(const std::string& filename, std::ios_base::openmode mode = std::ios_base::out);
    void close();
    bool is_open();
};
